@@ -1,7 +1,9 @@
 package Sah::Schema::isbn13;
 
-our $DATE = '2019-07-25'; # DATE
-our $VERSION = '0.006'; # VERSION
+# AUTHOR
+our $DATE = '2019-11-29'; # DATE
+our $DIST = 'Sah-Schemas-ISBN'; # DIST
+our $VERSION = '0.007'; # VERSION
 
 our $schema = [str => {
     summary => 'ISBN 13 number',
@@ -16,7 +18,7 @@ ISBN 10.
 
 _
     match => '\A[0-9]{13}\z',
-    'x.perl.coerce_rules' => ['str_to_isbn13'],
+    'x.perl.coerce_rules' => ['From_str::to_isbn13'],
 }, {}];
 
 1;
@@ -34,7 +36,7 @@ Sah::Schema::isbn13 - ISBN 13 number
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::isbn13 (from Perl distribution Sah-Schemas-ISBN), released on 2019-07-25.
+This document describes version 0.007 of Sah::Schema::isbn13 (from Perl distribution Sah-Schemas-ISBN), released on 2019-11-29.
 
 =head1 DESCRIPTION
 
